'use strict';

var React = require('react');
var DialogMixin = require('../mixins/DialogMixin');
var StringField = require('../fields/StringField');
var TextField = require('../fields/TextField');
var BooleanField = require('../fields/BooleanField');
var NumberField = require('../fields/NumberField');
var _ = require('lodash');

module.exports = function (options) {
  options = options || {};

  var title = options.title;
  var cancelButtonText = options.cancelButtonText;
  var submitButtonText = options.submitButtonText;
  var attributes = options.attributes;
  var attributeNames = _.keys(attributes);

  return React.createClass({
    displayName: 'Dialog',

    mixins: [DialogMixin],

    propTypes: {
      model: React.PropTypes.object.isRequired
    },

    getInitialState: function getInitialState() {
      var that = this;
      var model = this.props.model;

      // Create change callbacks
      this.onChangeCallbacks = _.reduce(attributeNames, function (callbacks, attributeName) {
        callbacks[attributeName] = function (event) {
          var newState = {};
          newState[attributeName] = event.target.value;
          that.setState(newState);
        };
        return callbacks;
      }, {});

      // Create initial state
      return _.reduce(attributeNames, function (initialState, attributeName) {
        initialState[attributeName] = model.data[attributeName];
        return initialState;
      }, {});
    },

    render: function render() {
      var formFields = _.map(attributeNames, function (attributeName) {
        var attribute = attributes[attributeName];
        if (attribute.type === 'string') {
          return React.createElement(StringField, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'text') {
          return React.createElement(TextField, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'boolean') {
          return React.createElement(BooleanField, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'number') {
          return React.createElement(NumberField, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else {
          throw new Error('Unrecognized attribute type: ' + attribute.type);
        }
      }.bind(this));

      return React.createElement(
        'div',
        { className: 'modal fade' },
        React.createElement(
          'div',
          { className: 'modal-dialog' },
          React.createElement(
            'div',
            { className: 'modal-content' },
            React.createElement(
              'div',
              { className: 'modal-header' },
              React.createElement(
                'button',
                { type: 'button', className: 'close', 'data-dismiss': 'modal' },
                React.createElement(
                  'span',
                  null,
                  '×'
                )
              ),
              React.createElement(
                'h4',
                { className: 'modal-title' },
                title
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-body' },
              React.createElement(
                'form',
                null,
                formFields
              )
            ),
            React.createElement(
              'div',
              { className: 'modal-footer' },
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-default', 'data-dismiss': 'modal' },
                cancelButtonText
              ),
              React.createElement(
                'button',
                { type: 'button', className: 'btn btn-primary', onClick: this.onSubmit },
                submitButtonText
              )
            )
          )
        )
      );
    }
  });
};